@@ -3,6 +3,7 @@ from .utils_config import UtilsConfig
 from .utils_env import UtilsEnv
 from .utils_id import UtilsId
 from .utils_image import UtilsImage
+from .utils_method import UtilsMethod
 from .utils_opencv import UtilsOpencv
 from .utils_ping import UtilsPing
 from .utils_random import UtilsRandom
@@ -15,6 +16,7 @@ __all__ = [
     UtilsEnv,
     UtilsId,
     UtilsImage,
+    UtilsMethod,
     UtilsOpencv,
     UtilsPing,
     UtilsRandom,
