@@ -32,6 +32,10 @@ class UtilsImage:
         return self.convert_image_pil_to_image_cv(self.open_image_pil(image_path))
 
     def save_image_pil(self, image_pil: Image, image_path: str) -> str:
+        # Make sure the image is in RGB mode
+        image_extension = image_path.split('.')[-1].lower()
+        if image_extension in ['jpg', 'jpeg']:
+            image_pil = image_pil.convert('RGB')
         image_pil.save(image_path, quality=100)
         return image_path
 
@@ -77,3 +81,10 @@ class UtilsImage:
         image_without_exif_pil = image_pil_main.new(image_pil.mode, image_pil.size)
         image_without_exif_pil.putdata(image_data)
         return image_without_exif_pil
+
+    def convert_to_jpg(self, image_path: str) -> str:
+        extension = image_path.split('.')[-1]
+        new_image_path = image_path.replace('.' + extension, '.jpg')
+        image_pil = self.open_image_pil(image_path)
+        self.save_image_pil(image_pil, new_image_path)
+        return new_image_path
